==> haskell-asn1-parse-0.9.5-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-9kvR8eHNgl34FcQGpg10Yp
key:                  asn1-parse-0.9.5-9kvR8eHNgl34FcQGpg10Yp
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  5beab9d099a36b9877a7a1c096f9ec1b
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-8.10.3/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/asn1-parse-0.9.5
hs-libraries:         HSasn1-parse-0.9.5-9kvR8eHNgl34FcQGpg10Yp
depends:
    asn1-encoding-0.9.6-CfTJG7McS45FhDsZ9XpHjo
    asn1-types-0.3.4-9Q8weyt114k80ekUf8gn4g base-4.14.1.0
    bytestring-0.10.12.0

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.5-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 asn1-parse
version:              0.9.5
visibility:           public
id:                   asn1-parse-0.9.5-8yWi6aNG89KBe0scPzwbt7
key:                  asn1-parse-0.9.5-8yWi6aNG89KBe0scPzwbt7
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.

category:             Data
abi:                  36b80a04cc6bd160b419faa1554cb87c
exposed:              True
exposed-modules:      Data.ASN1.Parse
import-dirs:          /usr/lib/ghc-8.10.3/site-local/asn1-parse-0.9.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/asn1-parse-0.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/asn1-parse-0.9.5
hs-libraries:         HSasn1-parse-0.9.5-8yWi6aNG89KBe0scPzwbt7
depends:
    asn1-encoding-0.9.6-HRxqKF0IITL1cpXBSz8Ixk
    asn1-types-0.3.4-6G39LBSjRw320WYwux8L87 base-4.14.1.0
    bytestring-0.10.12.0

haddock-interfaces:   /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html:         /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
